function [residual, g1, g2] = ACS_OutputTrendGap_loglinear_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 8, 1);

%
% Model equations
%

pi_star__ = 1+params(14)/400;
bet__ = 400/(400+params(13));
phi__ = params(1)*(1-params(18))/(params(18)*pi_star__^2*params(2));
pibar__ = pi_star__;
b__ = 1-1/(2*params(18));
yss__ = ((1-params(18))*params(17)^params(1))^(1/(params(1)+1/params(19)));
css__ = yss__/params(17);
cst__ = log(css__);
yst__ = log(yss__);
pst__ = log(pi_star__);
gst__ = log(params(17));
T67 = exp(params(1)*(y(7)+cst__)+1/params(19)*(y(6)+yst__));
T121 = exp(y(1)*params(5)+y(8)*(1-params(5))*params(3)+(1-params(5))*params(4)*(y(6)-y(2))+params(9)*x(4));
lhs =1;
rhs =exp((-y(4))+y(1)-y(8));
residual(1)= lhs-rhs;
lhs =1;
rhs =1/params(18)*(1-T67)+phi__*(exp(y(8)+pst__)-pibar__)*(exp(y(8)+pst__)*b__+pibar__*(1-b__))-phi__*bet__*exp(y(8)+pst__)*(exp(y(8)+pst__)-pibar__);
residual(2)= lhs-rhs;
lhs =exp(y(7)+cst__-y(6)-yst__);
rhs =exp((-y(3))-gst__)-phi__/2*(exp(y(8)+pst__)-pibar__)^2;
residual(3)= lhs-rhs;
lhs =exp(y(1));
rhs =T121;
residual(4)= lhs-rhs;
lhs =y(2);
rhs =y(2)*params(20)+y(6)*(1-params(20))-y(4)*params(20);
residual(5)= lhs-rhs;
lhs =y(3);
rhs =y(3)*params(6)+params(10)*x(2);
residual(6)= lhs-rhs;
lhs =y(4);
rhs =y(4)*params(7)+params(11)*x(1);
residual(7)= lhs-rhs;
lhs =y(5);
rhs =y(5)*params(8)+params(12)*x(3);
residual(8)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(8, 8);

  %
  % Jacobian matrix
  %

  g1(1,1)=(-exp((-y(4))+y(1)-y(8)));
  g1(1,4)=exp((-y(4))+y(1)-y(8));
  g1(1,8)=exp((-y(4))+y(1)-y(8));
  g1(2,6)=(-(1/params(18)*(-(1/params(19)*T67))));
  g1(2,7)=(-(1/params(18)*(-(params(1)*T67))));
  g1(2,8)=(-((exp(y(8)+pst__)*b__+pibar__*(1-b__))*phi__*exp(y(8)+pst__)+phi__*(exp(y(8)+pst__)-pibar__)*exp(y(8)+pst__)*b__-phi__*bet__*(exp(y(8)+pst__)*(exp(y(8)+pst__)-pibar__)+exp(y(8)+pst__)*exp(y(8)+pst__))));
  g1(3,3)=exp((-y(3))-gst__);
  g1(3,6)=(-exp(y(7)+cst__-y(6)-yst__));
  g1(3,7)=exp(y(7)+cst__-y(6)-yst__);
  g1(3,8)=phi__/2*exp(y(8)+pst__)*2*(exp(y(8)+pst__)-pibar__);
  g1(4,1)=exp(y(1))-params(5)*T121;
  g1(4,2)=(-(T121*(-((1-params(5))*params(4)))));
  g1(4,6)=(-((1-params(5))*params(4)*T121));
  g1(4,8)=(-((1-params(5))*params(3)*T121));
  g1(5,2)=1-params(20);
  g1(5,4)=params(20);
  g1(5,6)=(-(1-params(20)));
  g1(6,3)=1-params(6);
  g1(7,4)=1-params(7);
  g1(8,5)=1-params(8);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],8,64);
end
end
